import click
from dotenv import load_dotenv
import data
import plots

@click.group()
def cli():
    ...

if __name__ == "__main__":
    load_dotenv()

    # original bias ratings
    cli.add_command(data.scrape.download)
    cli.add_command(data.scrape.parse)
    cli.add_command(data.scrape.load)
    cli.add_command(data.scrape.normalize)
    cli.add_command(data.scrape.create_elections_table)

    cli.add_command(data.factcheck.parse_index)
    cli.add_command(data.factcheck.scrape)

    cli.add_command(data.links.create_table)
    cli.add_command(data.links.create_pca)
    cli.add_command(data.links.create_clusters)

    import word
    # cli.add_command(word.distance)
    # cli.add_command(word.train)
    cli.add_command(word.embed)
    cli.add_command(word.max_sequence)
    import bias
    cli.add_command(bias.parse)
    cli.add_command(bias.load)
    cli.add_command(bias.normalize)

    import mine
    cli.add_command(mine.embeddings)
    cli.add_command(mine.cluster)
    cli.add_command(mine.plot)

    import emotion
    cli.add_command(emotion.extract)
    cli.add_command(emotion.normalize)
    cli.add_command(emotion.analyze)
    cli.add_command(emotion.create_table)

    import sentence
    cli.add_command(sentence.embed)
    cli.add_command(sentence.create_avg_pca_table)

    from train import main as train_main
    cli.add_command(train_main.main)

    cli.add_command(plots.descriptive.articles_per_year)
    cli.add_command(plots.descriptive.distinct_publishers)
    cli.add_command(plots.descriptive.stories_per_publisher)
    cli.add_command(plots.descriptive.top_publishers)
    cli.add_command(plots.descriptive.common_tld)
    cli.add_command(plots.sentence.sentence_pca)
    cli.add_command(plots.sentence.avg_sentence_pca)
    cli.add_command(plots.emotion.emotion_over_time)
    cli.add_command(plots.emotion.emotion_regression)
    cli.add_command(plots.sentiment.over_time)
    cli.add_command(plots.sentiment.bias_over_time)
    cli.add_command(plots.sentiment.bias_vs_recent_winner)
    cli.add_command(plots.links.elbow)
    cli.add_command(plots.links.link_pca_clusters)
    cli.add_command(plots.classifier.pca_with_classes)

    cli()
