import os
from pathlib import Path
import duckdb
from enum import Enum
from urllib.parse import urlparse
from tld import get_tld
from tld.utils import update_tld_names
import sys

class Data(str, Enum):
    Titles = 'titles'

def data_dir():
    return Path(os.environ['DATA_MINING_DATA_DIR'])

def paths(name='app'):
    if 'app' in name:
        return Path(os.environ['DATA_MINING_APP_DIR'])
    if 'data' in name:
        return Path(os.environ['DATA_MINING_DATA_DIR'])
    if 'doc' in name:
        return Path(os.environ['DATA_MINING_DOCS_DIR'])
    if 'figure' in name:
        return Path(os.environ['DATA_MINING_DOCS_DIR']) / 'figures'

def connect():
    DATA_DIR = Path(os.environ['DATA_MINING_DATA_DIR'])
    # APP_DIR = Path(os.environ['DATA_MINING_APP_DIR'])
    DB = duckdb.connect(str(DATA_DIR / 'project.duckdb'))
    return DB

def from_db(t: Data):
    DATA_DIR = Path(os.environ['DATA_MINING_DATA_DIR'])
    # APP_DIR = Path(os.environ['DATA_MINING_APP_DIR'])
    DB = duckdb.connect(str(DATA_DIR / 'project.duckdb'))
    if t == Data.Titles:
        table = DB.sql("""
            select
                distinct
                title 
            from stories
            limit 100
        """).df()
    return table

def map_tld(x):
    try:
        res = get_tld(x, as_object=True)
        return res.fld
    except:
        print(f"'{x}' is not valid.", file=sys.stderr)
        return None

def ticklabels():
    return [ 
            'Left',
            'Left-Center',
            'Least Biased',
            'Right-Center',
            'Right',
        ]

def bias_label_to_int(rating:str, source: str = 'mbfc') -> int:
    if source == 'mbfc':
        mapping = {
            'Left' : 0,
            'Left-Center' : 1,
            'Least Biased' : 2,
            'Right-Center' : 3,
            'Right' : 4,
        }
    else:
        mapping = {
            'left' : 0,
            'left-center' : 1,
            'center' : 2,
            'right-center' : 3,
            'right' : 4,
        }
    try:
        return mapping[rating]
    except:
        print(f"no mapping for {rating}", file=sys.stderr)
        return -1

def bias_int_to_label(class_id: int, source: str = 'mbfc') -> str:
    if source == 'mbfc':
        mapping = {
            0 : 'Left',
            1 : 'Left-Center',
            2 : 'Least Biased',
            3 : 'Right-Center',
            4 : 'Right',
        }
    else:
        mapping = {
                0 : 'left',
                1 : 'left-center',
                2 : 'center',
                3 : 'right-center',
                4 : 'right',
        }
    try:
        return mapping[class_id]
    except:
        print(f"no mapping for {class_id}", file=sys.stderr)
        return -1
