from data.main import connect, paths
import numpy as np
from sklearn.cluster import MiniBatchKMeans
import click
from pathlib import Path
import seaborn as sns
import matplotlib.pyplot as plt
from enum import Enum, auto


@click.command(name="mine:embeddings")
def embeddings():
    data = np.load(paths('data') / "embeddings.npy")
    kmeans = MiniBatchKMeans(n_clusters=5,
                             random_state=0,
                             batch_size=6,
                             n_init="auto")
    model = kmeans.fit(data)
    clusters = model.predict(data)

    db = connect()

    stories = db.sql("""
        select
            id
        from stories
        order by id desc
    """).df()
    stories['cluster'] = clusters

    db.execute("drop table clusters")
    db.execute("CREATE TABLE clusters (story_id BIGINT, cluster integer)")
    db.append("clusters", stories)

@click.command(name="mine:cluster")
def cluster():

    import pandas as pd
    pd.set_option('display.max_rows', 100)
    pd.set_option('display.max_columns', 500)
    pd.set_option('display.width', 1000)
    df = db.sql("""
        select
            s.publisher
            ,c.cluster
            ,count(1) as total
        from clusters c
        join stories s
        on s.id = c.story_id
        group by
        s.publisher, c.cluster
    """).df()

    pivoted = df.pivot(index='publisher', columns='cluster', values='total').sort_values([0], ascending=False)
    pivoted[:25]

    db.sql("""
        select
            publisher
            ,title
        from clusters c
        join stories s
        on s.id = c.story_id
        where c.cluster = 0
    """)

    len(stories)
    data.shape

class PlotName(str, Enum):
    TitleLength = "title_len"
    OutletStories = "outlet_stories"

@click.command(name='mine:plot')
@click.option('-n', '--name', required=True, type=click.Choice(PlotName))
@click.option('-o', '--output', required=False, type=click.Path())
def plot(name: PlotName, output: Path):
    output = output if output else paths('figures') / f'{name}.png'
    if name == PlotName.TitleLength:
        fig, ax = plt.subplots(1,1)
        data = db.sql("""
            select
            length(title) as len
            from stories
        """).df()
        sns.histplot(x=data['len'], bins=50, ax=ax[0])
        ax[0].set(ylabel="count", xlabel="title length")
    elif name == PlotName.OutletStories:

        data = db.sql("""
            with cte as (
            select
                count(1) as stories
            from stories
            group by outlet
            )
            select
                row_number() over(order by stories desc) as id
                ,log(stories) as log_count
            from cte
        """).df()

        fig, ax = plt.subplots(1,1)
        sns.lineplot(x=data['id'], y=data['log_count'], ax=ax)
        from matplotlib.ticker import ScalarFormatter
        ax.set(yscale='log', xlabel="outlet", ylabel="log(count of stories)", majorformater=ScalarFormatter)
        plt.show()

    else:
        raise NotImplementedError("option unrecognized")
    plt.savefig(output)

def main():
    db.sql("""
        select
            count(distinct publisher)
        from stories
    """)

    db.sql("""
        with cte as (
        select
            distinct title
        from stories
        )
        select
            max(length(title)) as max
            ,min(length(title)) as min
            ,avg(length(title)) as avg
            ,sum(length(title)) as characters
        from cte
    """).fetchall()
    # let's calculate the size of the word embeddings stored as a list in the database
    # db.sql("""
    #     with cte as (
    #     select
    #         distinct title
    #     from stories
    #     )
    #     ...
    # """)

    # db.sql("""
    #     select
    #         count(distinct url)
    #     from stories
    # """)
