import click
from data.main import connect, bias_label_to_int, ticklabels
import os
from pathlib import Path
import seaborn as sns
import matplotlib.pyplot as plt
import numpy as np
import pandas as pd

@click.command('plot:bias-hist')
def hist():
    save_to = paths('figures') / "bias_hist.png"

    with connect() as db:
        data = db.sql("""
            SELECT
                p.ordinal
                ,count(1) as stories
            FROM stories s
            JOIN mbfc.publisher_stories ps
            ON s.id = ps.story_id
            JOIN mbfc.publishers p
            ON ps.publisher_id = p.id
            WHERE ordinal != -1
            GROUP BY
                p.ordinal
        """).df()


    ax = sns.barplot(x=data['ordinal'], y=data['stories'], color='tab:blue')
    ax.set(title="count of stories per bias rating", xlabel="bias rating", xticklabels=ticklabels())
    plt.tight_layout()
    plt.savefig(save_to)
    plt.close()
    print(f"saved: {save_to}")

@click.command('plot:bias-publisher-hist')
def publisher_hist():
    save_to = paths('figures') / "bias_publisher_hist.png"

    with connect() as db:
        data = db.sql("""
            SELECT
                p.ordinal
                ,count(distinct p.id) as publishers
            FROM mbfc.publishers p
            JOIN mbfc.publisher_stories ps
            ON ps.publisher_id = p.id
            WHERE ordinal != -1
            GROUP BY
                p.ordinal
        """).df()

    ax = sns.barplot(x=data['ordinal'], y=data['publishers'], color='tab:blue')
    ax.set(title="count of publishers per bias rating", xlabel="bias rating", xticklabels=ticklabels())
    plt.tight_layout()
    plt.savefig(save_to)
    plt.close()
    print(f"saved: {save_to}")
