import click
from data.main import connect
import os
import seaborn as sns
import matplotlib.pyplot as plt
from pathlib import Path

@click.command('plot:pca-with-classes')
@click.option('--source', type=click.Choice(['links', 'normalized', 'onehot']), default='links')
def pca_with_classes(source):

    save_to = paths('figures') / f"link_{source}_pca_with_classes.png"

    with connect() as db:
        df = db.query(f"""
            SELECT
                p.tld
                ,p.bias
                ,c.first
                ,c.second
                --,round(cast(b.agree as float) / (b.agree + b.disagree), 2) ratio
            FROM mbfc.publishers p
            JOIN publisher_pca_{source} c
            ON c.publisher_id = p.id
            WHERE p.ordinal != -1
            ORDER BY p.ordinal
        """).df()

    ax = sns.relplot(df, x='first', y='second', hue='bias', col='bias', s=100, palette='rainbow')
    ax.set(xlabel="first pca component", 
           ylabel="second pca component")
    ax.figure.suptitle="pca components vs. bias labels"
    plt.savefig(save_to)
    plt.close()
    print(f"saved: {save_to}")
    os.system(f'xdg-open {save_to}')
