from torch.utils.data import Dataset
from data.main import connect, data_dir
from bias import label_to_int
import numpy as np
import pandas as pd

class NewsDataset(Dataset):
    def __init__(self):
        self.embeddings = np.load(data_dir() / 'embeddings.npy')
        embedding_ids = pd.DataFrame(np.load(data_dir() / 'embedding_ids.npy'), columns=['id']).reset_index()

        DB = connect()
        query = """
            SELECT
                s.id
                ,b.label
                ,count(1) over (partition by publisher_id) as stories
            FROM stories s
            JOIN publisher_bias b
            ON b.id = s.publisher_id
            WHERE b.label != 'allsides'
        """
        data = DB.sql(query).df()
        DB.close()

        data['label'] = data['label'].apply(lambda x: label_to_int(x))
        data = data.merge(embedding_ids)
        self.data = data

    def __len__(self):
        return len(self.data)

    def __getitem__(self, idx):
        row = self.data.iloc[idx]
        y = row['label']
        # x = np.concatenate((self.embeddings[row['index']], [row['stories']])).astype(np.float32)
        x = self.embeddings[row['index']]
        return x, y
